==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/DeploymentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.DeploymentResult
import com.pulumi.azurenative.securityinsights.kotlin.enums.DeploymentState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Description about a deployment.
 * @property deploymentId Deployment identifier.
 * @property deploymentLogsUrl Url to access repository action logs.
 * @property deploymentResult The outcome of the deployment.
 * @property deploymentState Current status of the deployment.
 * @property deploymentTime The time when the deployment finished.
 */
public data class DeploymentArgs(
    public val deploymentId: Output<String>? = null,
    public val deploymentLogsUrl: Output<String>? = null,
    public val deploymentResult: Output<Either<String, DeploymentResult>>? = null,
    public val deploymentState: Output<Either<String, DeploymentState>>? = null,
    public val deploymentTime: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs =
        com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs.builder()
            .deploymentId(deploymentId?.applyValue({ args0 -> args0 }))
            .deploymentLogsUrl(deploymentLogsUrl?.applyValue({ args0 -> args0 }))
            .deploymentResult(
                deploymentResult?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .deploymentState(
                deploymentState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .deploymentTime(deploymentTime?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DeploymentArgs].
 */
@PulumiTagMarker
public class DeploymentArgsBuilder internal constructor() {
    private var deploymentId: Output<String>? = null

    private var deploymentLogsUrl: Output<String>? = null

    private var deploymentResult: Output<Either<String, DeploymentResult>>? = null

    private var deploymentState: Output<Either<String, DeploymentState>>? = null

    private var deploymentTime: Output<String>? = null

    /**
     * @param value Deployment identifier.
     */
    @JvmName("xdxqgmqvnamyjefh")
    public suspend fun deploymentId(`value`: Output<String>) {
        this.deploymentId = value
    }

    /**
     * @param value Url to access repository action logs.
     */
    @JvmName("lxvtkqssqfyopwcq")
    public suspend fun deploymentLogsUrl(`value`: Output<String>) {
        this.deploymentLogsUrl = value
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("idyyhsxhptmueadk")
    public suspend fun deploymentResult(`value`: Output<Either<String, DeploymentResult>>) {
        this.deploymentResult = value
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("duwvlyfqovahrlvr")
    public suspend fun deploymentState(`value`: Output<Either<String, DeploymentState>>) {
        this.deploymentState = value
    }

    /**
     * @param value The time when the deployment finished.
     */
    @JvmName("vuwpjeutnbmwkonr")
    public suspend fun deploymentTime(`value`: Output<String>) {
        this.deploymentTime = value
    }

    /**
     * @param value Deployment identifier.
     */
    @JvmName("cnorlloatkvghygb")
    public suspend fun deploymentId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentId = mapped
    }

    /**
     * @param value Url to access repository action logs.
     */
    @JvmName("ydmypasximqvbjwj")
    public suspend fun deploymentLogsUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentLogsUrl = mapped
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("gvgdmxnqfdthybmr")
    public suspend fun deploymentResult(`value`: Either<String, DeploymentResult>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentResult = mapped
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("wdoylnbeanfvpkhf")
    public fun deploymentResult(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentResult>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentResult = mapped
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("gwtbninlkfaluavc")
    public fun deploymentResult(`value`: DeploymentResult) {
        val toBeMapped = Either.ofRight<String, DeploymentResult>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentResult = mapped
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("kaaidawlnhthowjw")
    public suspend fun deploymentState(`value`: Either<String, DeploymentState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentState = mapped
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("xlaticfxxmvgepfh")
    public fun deploymentState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentState = mapped
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("lgcdlrpqjfhcuhbw")
    public fun deploymentState(`value`: DeploymentState) {
        val toBeMapped = Either.ofRight<String, DeploymentState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentState = mapped
    }

    /**
     * @param value The time when the deployment finished.
     */
    @JvmName("kyhlrsylypfrafwj")
    public suspend fun deploymentTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentTime = mapped
    }

    internal fun build(): DeploymentArgs = DeploymentArgs(
        deploymentId = deploymentId,
        deploymentLogsUrl = deploymentLogsUrl,
        deploymentResult = deploymentResult,
        deploymentState = deploymentState,
        deploymentTime = deploymentTime,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/DeploymentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.DeploymentResult
import com.pulumi.azurenative.securityinsights.kotlin.enums.DeploymentState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Description about a deployment.
 * @property deploymentId Deployment identifier.
 * @property deploymentLogsUrl Url to access repository action logs.
 * @property deploymentResult The outcome of the deployment.
 * @property deploymentState Current status of the deployment.
 * @property deploymentTime The time when the deployment finished.
 */
public data class DeploymentArgs(
    public val deploymentId: Output<String>? = null,
    public val deploymentLogsUrl: Output<String>? = null,
    public val deploymentResult: Output<Either<String, DeploymentResult>>? = null,
    public val deploymentState: Output<Either<String, DeploymentState>>? = null,
    public val deploymentTime: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs =
        com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs.builder()
            .deploymentId(deploymentId?.applyValue({ args0 -> args0 }))
            .deploymentLogsUrl(deploymentLogsUrl?.applyValue({ args0 -> args0 }))
            .deploymentResult(
                deploymentResult?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .deploymentState(
                deploymentState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .deploymentTime(deploymentTime?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DeploymentArgs].
 */
@PulumiTagMarker
public class DeploymentArgsBuilder internal constructor() {
    private var deploymentId: Output<String>? = null

    private var deploymentLogsUrl: Output<String>? = null

    private var deploymentResult: Output<Either<String, DeploymentResult>>? = null

    private var deploymentState: Output<Either<String, DeploymentState>>? = null

    private var deploymentTime: Output<String>? = null

    /**
     * @param value Deployment identifier.
     */
    @JvmName("tnrxynrckfjfgkla")
    public suspend fun deploymentId(`value`: Output<String>) {
        this.deploymentId = value
    }

    /**
     * @param value Url to access repository action logs.
     */
    @JvmName("qxrvoyavjibdctfn")
    public suspend fun deploymentLogsUrl(`value`: Output<String>) {
        this.deploymentLogsUrl = value
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("xqphfabsjeuoawky")
    public suspend fun deploymentResult(`value`: Output<Either<String, DeploymentResult>>) {
        this.deploymentResult = value
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("puhpicankhxrnmmm")
    public suspend fun deploymentState(`value`: Output<Either<String, DeploymentState>>) {
        this.deploymentState = value
    }

    /**
     * @param value The time when the deployment finished.
     */
    @JvmName("dkqyqumgnidiancp")
    public suspend fun deploymentTime(`value`: Output<String>) {
        this.deploymentTime = value
    }

    /**
     * @param value Deployment identifier.
     */
    @JvmName("ghejtkikdyoktrxt")
    public suspend fun deploymentId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentId = mapped
    }

    /**
     * @param value Url to access repository action logs.
     */
    @JvmName("lhoyxbqwuqqtseup")
    public suspend fun deploymentLogsUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentLogsUrl = mapped
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("nvuhefrdqeqjotrc")
    public suspend fun deploymentResult(`value`: Either<String, DeploymentResult>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentResult = mapped
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("oodixepltlbjxvge")
    public fun deploymentResult(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentResult>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentResult = mapped
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("hmuaxagteiajhkkf")
    public fun deploymentResult(`value`: DeploymentResult) {
        val toBeMapped = Either.ofRight<String, DeploymentResult>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentResult = mapped
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("oyonmbxqoymalkou")
    public suspend fun deploymentState(`value`: Either<String, DeploymentState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentState = mapped
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("wtyjwnkvtrwjjfgf")
    public fun deploymentState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentState = mapped
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("vkephtmyfnnlwhko")
    public fun deploymentState(`value`: DeploymentState) {
        val toBeMapped = Either.ofRight<String, DeploymentState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentState = mapped
    }

    /**
     * @param value The time when the deployment finished.
     */
    @JvmName("nljhtbocvgpmvmax")
    public suspend fun deploymentTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentTime = mapped
    }

    internal fun build(): DeploymentArgs = DeploymentArgs(
        deploymentId = deploymentId,
        deploymentLogsUrl = deploymentLogsUrl,
        deploymentResult = deploymentResult,
        deploymentState = deploymentState,
        deploymentTime = deploymentTime,
    )
}
